@@ -1,3 +1,5 @@
+import time
+
 import etcd3
 #往etcd中存数据
 from etcd3.events import DeleteEvent
@@ -9,17 +11,32 @@ b = client.get('aaa')                        #查看etcd中的键值
 print(r)
 print(b)
 events_iterator, cancel = client.watch('aaa')
-client.put('aaa', '111')
-client.delete('aaa')
-for event in events_iterator:
-    print(event)
-    t = type(event)
-    if t == DeleteEvent:
-        print("删除")
 
-#监听etcd中aaa键 是否发生改变，
-for x in client.get_all(keys_only=True):
-    print(x[1].key)
+lease_id = int(time.time())
+ttl = 10
+lease = client.lease(ttl, lease_id)
+client.put('aaa', '111', lease)
+time.sleep(8)
+print(client.get("aaa"))
+next(client.refresh_lease(lease_id))
+time.sleep(4)
+
+print(client.get("aaa"))
+
+
+
+
+# time.sleep(1000)
+# client.delete('aaa')
+# for event in events_iterator:
+#     print(event)
+#     t = type(event)
+#     if t == DeleteEvent:
+#         print("删除")
+#
+# #监听etcd中aaa键 是否发生改变，
+# for x in client.get_all(keys_only=True):
+#     print(x[1].key)
 #
 # # res = client.delete_prefix(prefix="")
 # # print(res)
